@@ -72,12 +72,12 @@ class PredictionSummaryComponent(ExplainerComponent):
                     make_hideable(
                         dbc.Col([
                             dbc.Label("Show Percentile:"),
-                            dbc.FormGroup(
+                            dbc.Row(
                             [
                                 dbc.RadioButton(
                                     id='modelprediction-percentile-'+self.name, 
                                     className="form-check-input",
-                                    checked=self.percentile),
+                                    value=self.percentile),
                                 dbc.Label("Show percentile",
                                         html_for='modelprediction-percentile'+self.name, 
                                         className="form-check-label"),
@@ -91,13 +91,13 @@ class PredictionSummaryComponent(ExplainerComponent):
                     ], md=12)
                 ])
             ])
-        ])
+        ], class_name="h-100")
 
     def component_callbacks(self, app):
         @app.callback(
             Output('modelprediction-'+self.name, 'children'),
             [Input('modelprediction-index-'+self.name, 'value'),
-             Input('modelprediction-percentile-'+self.name, 'checked'),
+             Input('modelprediction-percentile-'+self.name, 'value'),
              Input('pos-label-'+self.name, 'value')])
         def update_output_div(index, include_percentile, pos_label):
             if index is not None:
@@ -189,39 +189,38 @@ class ImportancesComponent(ExplainerComponent):
                 dbc.Row([
                     make_hideable(
                         dbc.Col([
-                            dbc.FormGroup([
                                 dbc.Label("Importances type:"),
                                 dbc.Select(
                                     options=[
-                                        {'label': 'Permutation Importances', 
-                                        'value': 'permutation'},
-                                        {'label': 'SHAP values', 
-                                        'value': 'shap'}
+                                        {'label': 'Permutation Importances',
+                                         'value': 'permutation'},
+                                        {'label': 'SHAP values',
+                                         'value': 'shap'}
                                     ],
                                     value=self.importance_type,
+                                    size='sm',
                                     id='importances-permutation-or-shap-'+self.name,
-                                    #inline=True,
                                 ),
-                                
-                            ], id='importances-permutation-or-shap-form-'+self.name),
-                            dbc.Tooltip("Select Feature importance type: \n"
-                                    "Permutation Importance: How much does performance metric decrease when shuffling this feature?\n"
-                                    "SHAP values: What is the average SHAP contribution (positive or negative) of this feature?",
-                                    target='importances-permutation-or-shap-form-'+self.name),
-                        ], md=3), self.hide_type),
+                                dbc.Tooltip("Select Feature importance type: \n"
+                                            "Permutation Importance: How much does performance metric decrease when shuffling this feature?\n"
+                                            "SHAP values: What is the average SHAP contribution (positive or negative) of this feature?",
+                                            target='importances-permutation-or-shap-form-'+self.name),
+                                ], md=3, id='importances-permutation-or-shap-form-'+self.name),
+                        self.hide_type),
                     make_hideable(
                         dbc.Col([
-                            html.Label('Depth:', id='importances-depth-label-'+self.name),
+                            dbc.Label('Depth:', id='importances-depth-label-'+self.name),
                             dbc.Select(id='importances-depth-'+self.name,
                                         options = [{'label': str(i+1), 'value':i+1} 
                                                     for i in range(self.explainer.n_features)],
+                                        size='sm',
                                         value=self.depth),
                             dbc.Tooltip("Select how many features to display", target='importances-depth-label-'+self.name)
                         ], md=2), self.hide_depth),   
                     make_hideable(
                             dbc.Col([self.selector.layout()
                         ], width=2), hide=self.hide_selector)    
-                ], form=True),
+                ]),
                 dbc.Row([
                     dbc.Col([
                         dcc.Loading(id='importances-graph-loading-'+self.name,
@@ -236,7 +235,7 @@ class ImportancesComponent(ExplainerComponent):
                         ], md=2, align="start"), hide=self.hide_popout),
                 ], justify="end"),
             ])         
-        ])
+        ], class_name="h-100")
 
     def to_html(self, state_dict=None, add_header=True):
         args = self.get_state_args(state_dict)
@@ -302,7 +301,7 @@ class FeatureDescriptionsComponent(ExplainerComponent):
                 dbc.Row([
                     make_hideable(
                         dbc.Col([
-                            dbc.FormGroup([
+                            dbc.Row([
                                 dbc.Label("Sort Features:"),
                                 dbc.Select(
                                     options=[
@@ -312,6 +311,7 @@ class FeatureDescriptionsComponent(ExplainerComponent):
                                         'value': 'shap'}
                                     ],
                                     value=self.sort,
+                                    size='sm',
                                     id='feature-descriptions-table-sort-'+self.name,
                                 ), 
                             ]),
@@ -319,14 +319,14 @@ class FeatureDescriptionsComponent(ExplainerComponent):
                                         "mean absolute SHAP value to lowest.",
                                     target='feature-descriptions-table-sort-'+self.name),
                         ], md=3), self.hide_sort),   
-                ], form=True),
+                ]),
                 dbc.Row([
                     dbc.Col([
                         html.Div(id='feature-descriptions-table-'+self.name)
                     ]),
                 ]),
             ])
-        ])
+        ], class_name="h-100")
 
     def to_html(self, state_dict=None, add_header=True):
         args = self.get_state_args(state_dict)
@@ -432,7 +432,7 @@ class PdpComponent(ExplainerComponent):
         """
         self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
         self.index_selector = IndexSelector(explainer, 'pdp-index-'+self.name,
-                                    index=index, index_dropdown=index_dropdown)
+                                    index=index, index_dropdown=index_dropdown, **kwargs)
 
         self.popout = GraphPopout('pdp-'+self.name+'popout', 'pdp-graph-'+self.name, self.title, self.description)
 
@@ -457,7 +457,9 @@ class PdpComponent(ExplainerComponent):
                             dbc.Select(id='pdp-col-'+self.name,       
                                 options=[{'label': col, 'value':col} 
                                             for col in self.explainer.columns_ranked_by_shap()],
-                                value=self.col),
+                                value=self.col,
+                                size='sm'
+                            ),
                         ], md=4), hide=self.hide_col),
                     make_hideable(
                         dbc.Col([
@@ -469,7 +471,7 @@ class PdpComponent(ExplainerComponent):
                     make_hideable(
                         dbc.Col([self.selector.layout()
                     ], width=2), hide=self.hide_selector),
-                ], form=True),
+                ]),
                 dbc.Row([
                     dbc.Col([
                         dcc.Loading(id='loading-pdp-graph-'+self.name, 
@@ -489,7 +491,7 @@ class PdpComponent(ExplainerComponent):
                 dbc.Row([
                     make_hideable(
                         dbc.Col([
-                            dbc.FormGroup([
+                            dbc.Row([
                                 dbc.Label("Drop fill:"),
                                 dbc.Tooltip("Drop all observations with feature values "
                                         f"equal to {self.explainer.na_fill} from the plot. "
@@ -536,18 +538,21 @@ class PdpComponent(ExplainerComponent):
                                     dbc.Tooltip("How to sort the categories: Alphabetically, most common "
                                                 "first (Frequency), or highest mean absolute SHAP value first (Shap impact)", 
                                                 target='pdp-categories-sort-label-'+self.name),
-                                    dbc.Select(id='pdp-categories-sort-'+self.name,
-                                            options = [{'label': 'Alphabetically', 'value': 'alphabet'},
-                                                        {'label': 'Frequency', 'value': 'freq'},
-                                                        {'label': 'Shap impact', 'value': 'shap'}],
-                                            value=self.cats_sort),
+                                    dbc.Select(
+                                        id='pdp-categories-sort-'+self.name,
+                                        options = [{'label': 'Alphabetically', 'value': 'alphabet'},
+                                                    {'label': 'Frequency', 'value': 'freq'},
+                                                    {'label': 'Shap impact', 'value': 'shap'}],
+                                        value=self.cats_sort,
+                                        size='sm'
+                                    ),
                                 ])], 
                             id='pdp-categories-sort-div-'+self.name,
                             style={} if self.col in self.explainer.cat_cols else dict(display="none")
                         ), hide=self.hide_cats_sort),
-                ], form=True),
+                ]),
             ]), hide=self.hide_footer)
-        ])
+        ], class_name="h-100")
 
     def get_state_tuples(self):
         _state_tuples = super().get_state_tuples()
@@ -626,6 +631,9 @@ class PdpComponent(ExplainerComponent):
                     gridpoints=gridpoints, sort=sort, pos_label=pos_label)
 
 
+
+
+
 class FeatureInputComponent(ExplainerComponent):
     def __init__(self, explainer, title="Feature Input", name=None,
                     subtitle="Adjust the feature values to change the prediction",
@@ -665,6 +673,7 @@ class FeatureInputComponent(ExplainerComponent):
         assert len(explainer.columns) == len(set(explainer.columns)), \
             "Not all X column names are unique, so cannot launch FeatureInputComponent component/tab!"
             
+        self.index_input = IndexSelector(explainer, name='feature-input-index-'+self.name, **kwargs)
         self.index_name = 'feature-input-index-'+self.name
         
         
@@ -698,10 +707,11 @@ class FeatureInputComponent(ExplainerComponent):
     def _generate_dash_input(self, col, onehot_cols, onehot_dict, cat_dict):
         if col in cat_dict:
             col_values = cat_dict[col]
-            return dbc.FormGroup([
+            return html.Div([
                     dbc.Label(col),
                     dcc.Dropdown(id='feature-input-'+col+'-input-'+self.name, 
                              options=[dict(label=col_val, value=col_val) for col_val in col_values],
+                             style={"width": "100%"},
                              clearable=False),
                     dbc.FormText(f"Select any {col}") if not self.hide_range else None,
                 ])   
@@ -713,18 +723,19 @@ class FeatureInputComponent(ExplainerComponent):
             if any(self.explainer.X[self.explainer.onehot_dict[col]].sum(axis=1) == 0):
                 col_values.append(self.explainer.onehot_notencoded[col])
                 display_values.append(self.explainer.onehot_notencoded[col])
-            return dbc.FormGroup([
+            return html.Div([
                     dbc.Label(col),
                     dcc.Dropdown(id='feature-input-'+col+'-input-'+self.name, 
                              options=[dict(label=display, value=col_val) 
                                         for display, col_val in zip(display_values, col_values)],
+                             style={"width": "100%"},
                              clearable=False),
                     dbc.FormText(f"Select any {col}") if not self.hide_range else None,
                 ])   
         else:
             min_range = np.round(self.explainer.X[col][lambda x: x != self.explainer.na_fill].min(), 2)
             max_range = np.round(self.explainer.X[col][lambda x: x != self.explainer.na_fill].max(), 2)
-            return dbc.FormGroup([
+            return html.Div([
                     dbc.Label(col),
                     dbc.Input(id='feature-input-'+col+'-input-'+self.name, type="number"),
                     dbc.FormText(f"Range: {min_range}-{max_range}") if not self.hide_range else None
@@ -776,16 +787,12 @@ class FeatureInputComponent(ExplainerComponent):
                 dbc.Row([
                     make_hideable(
                             dbc.Col([
-                                dbc.Label(f"{self.explainer.index_name}:"),
-                                dcc.Dropdown(id='feature-input-index-'+self.name, 
-                                    options = [{'label': str(idx), 'value':idx} 
-                                                    for idx in self.explainer.get_index_list()],
-                                    value=self.index)
+                                self.index_input.layout()
                             ], md=4), hide=self.hide_index), 
-                    ], form=True),
+                    ]),
                 input_row,
             ])
-        ])
+        ], class_name="h-100")
 
     def to_html(self, state_dict=None, add_header=True):
         args = self.get_state_args(state_dict)
@@ -802,9 +809,10 @@ class FeatureInputComponent(ExplainerComponent):
         return html
 
     def component_callbacks(self, app):
+
         @app.callback(
             [*self._feature_callback_outputs],
-            [Input('feature-input-index-'+self.name, 'value')]
+            [Input(self.index_name, 'value')]
         )
         def update_whatif_inputs(index):
             if index is None or not self.explainer.index_exists(index):
